@@ -169,7 +169,7 @@ def _options_for_dryrun(options, outs_dir):
 
 def _options_for_rebot(options, datasources, start_time_string, end_time_string):
     rebot_options = options.copy()
-    rebot_options['name'] = ', '.join(datasources)
+    rebot_options['name'] = options.get('name', ', '.join(datasources))
     rebot_options['starttime'] = start_time_string
     rebot_options['endtime'] = end_time_string
     rebot_options['output'] = rebot_options.get('output', 'output.xml')
